# -*- coding: utf-8 -*-

#       idc_dim_edit.py        2020.3.25   kita
#!! 寸法編集 Script(長瀬氏監修)

# 必要なファイル
#   idc_dim_edit.py   my_module.py  icd_dim_edit.txt 

# 参考  icd_test_text.py
#       SxEntSeg\EditText\EditText.cs
#       SxEntSeg\CreateText\CreateText.cs
#       SxEntSeg\GetGeom\GetDimAttrib.cs
#       SxEntSeg\SetDimTextSize\SetDimTextSize.cs
#       SxEntSeg\GetGeomList\GetGeomList.cs

# 起動方法
# [path] py icd_dim_edit.py

# 履歴
# 2020.3.29     タップ、キリ穴の寸法注記追加
# 2020.5.15     Ver.0.92    他のコマンドが選択されると終了するように修正
# 2020.6.17     Ver.0.93    ザグリ穴の名前変更に対応。ついでにサラ穴への対応
# 2020.7.8      Ver.0.94    桁数が-1に戻ってしまうバグを修正
#                            geom.txtinfo.dimval_type = None　を追記 これは間違いでした
# 2020.9.3      Ver.0.95    桁数が-1に戻ってしまうバグを修正
#                            opt = None
# 2020.10.3     Ver.0.96    畠さんの中心線自動回転プログラムを追加
# 2020.10.7     ver.0.97    キリ穴深さ追記部分に「キリ」を追加（「ｷﾘ」だけではなかった!!)
# 2021.3.21                 参考の「()」を前置文字、後置文字に変更（長瀬)
# 2021.1.10     ver.0.98    半角、倍角相互変換追加
# 2021.4. 5                 小数点半角にする（長瀬）
# 2021.4.23                 複数行の文字列が1行になってしまうのを修正
# 2021.4.24                 (R)寸法化追加,円筒カム角度追加
# 2021.5.15                 長瀬が追記した不具合を修正、レーザー加工穴対応
# 2021.8.6                  半角、全角変換でスペースやコンマを変換しない（半角のまま残す）
# 2021.8.31                 半角、全角変換で文字修飾文字列({U等)を変換しない
# 2021.9.3                  畠さんの公差穴寸法対応(長瀬)
# 2021.10.31                連続角度寸法追加
# 2021.11.23                囲み文字、下線文字を追加(長瀬)
# 2021.12.4                 一般仕上げボタン時に『機械部品』になっていたら配置できないを解決(長瀬)
# 2022.1.4                  文字置換のボタンを追加しました。(長瀬)
# 2022.6.8                  実寸ボタンを追加しました。（いらない）（長瀬）
# 2022.12.05                ガスネジ対応(長瀬)
# 2023. 2.10                寸法関係コマンド追加
# 2023.8.10                 喜多さんのCL作図と展開図補助プログラムを追加（長瀬）
# 2023.9.30                 喜多さんの公差穴寸法コマンド呼び出しを追加（長瀬）
#                           製図時に欲しいボタンを追加（長瀬）

import tkinter as tk
from tkinter import *
from tkinter import ttk
#import tkinter.ttk as ttk       # ComboBoxを使うのに必要
import sys                                  # 引数処理に必要なsys module
import subprocess
import os
#from time import sleep
import codecs
import zen_han              # 全角<-->半角変換
import re                   # 文字列から数値を取り出す 抽出
import math                 # カム外径計算に使用
import my_module as mmd

import clr
clr.AddReference('sxnet')
from sxnet import *

SxSys.init(3999)


dim_edit_fn = 'icd_dim_edit.txt'    

# マウスクリックの受付
opt = SxOptSelect()
#opt.ent_mode = SxSys.ENTMODE_MULTI
opt.ent_mode = SxSys.ENTMODE_SEG        #要素の検索モードを、[要]にする
# SxSys.ENTMODE_SEG:実像部品/パーツのメンバセグメントを選択した場合に、 セグメントを返答します。
opt.select_ent = True
#opt.select_pos = True
opt.select_seg = True
opt.select_go = True

#--------------------------------
# ヘルプボタン
#--------------------------------
def push_help():
  #cmd = 'notepad '+path+'icd_dim_edit.hlp'
  cmd = 'notepad  icd_dim_edit.hlp'
  #cmd = 'notepad '+path+'icd_add_word_menu.txt'
  #result = subprocess.call(cmd,shell=True)
  result = subprocess.Popen(cmd,shell=True)

#--------------------------------
#   マウスピック
#--------------------------------
def get_seg():
    inf = SxSys.select(opt)     # マウスピック
    try:
        if inf.status == SxInfSelect.STATUS_GO:   # @GO
            #print('GOが選択されました')
            seg = False
        elif inf.status == SxInfSelect.STATUS_ENT:  # segment 選択
            seg = inf.ent   # 選択された要素(Segment)を返す

    except:
        print('\n\n  寸法、文字列が選択されませんでした')
        seg = None
            
    return seg
 
#--------------------------------
#   Set Mesge 
#--------------------------------
def set_msg(msg):
    e_msg.delete(0,tk.END)
    e_msg.insert(0,msg)

#------------------------------------------------------------
# 寸法の前に記号を追加する 
#------------------------------------------------------------

def add_mark(seg,mk_no):
    geom = seg.getGeom() # Segmentのデーター構造オブジェクト
    geom_nm = geom.ToString()
    #print(geom_nm)
    #if geom_nm == "sxnet.SxGeomLengthDim":   # 長さ寸法
    if geom_nm.find('Dim') > -1:   # 寸法
        opt = SxOptDimEdit()      # 寸法線編集実行オプションクラス optは継承されない!
        opt = None                # これで継承される 
        
        m3 = geom.txtinfo.mark3     # 既存のマークNo
        if mk_no == 9:      # 任意のマーク
            if  m3 == mk_no:
                geom.txtinfo.mark3 = 0
            else:
                geom.txtinfo.mark3 = mk_no
                geom.txtinfo.opt_word = mk
        else:
            if m3 == mk_no:
                geom.txtinfo.mark3 = 0
            else:
                geom.txtinfo.mark3 = mk_no
                
        #geom.txtinfo.dimval_type = True     # Trueにしないと擬寸になってしまう 
        seg.editDimText(geom.txtinfo,opt)
    
    else: print('\n  寸法ではありません\007')

def push_mark():
    #set_msg('寸法ピック')
    #global mk_no, mk
    if v_mk.get() == 'φ': mk_no = 1
    elif v_mk.get() == '□': mk_no = 2
    elif v_mk.get() == 'R': mk_no = 3
    elif v_mk.get() == 'C': mk_no = 4
    elif v_mk.get() == 't': mk_no = 5
    elif v_mk.get() == 'M': mk_no = 6
    elif v_mk.get() == '⌒': mk_no = 7
    elif v_mk.get() == 'CR': mk_no = 8
    else: mk_no = 9; mk = v_mk.get()


    loop = True
    while loop:
        seg = get_seg()
        if seg == False: loop = False; break    # @G0
        #elif seg == None: continue
        elif seg == None: break     # 2020.5.15 終了 
        else: add_mark(seg,mk_no)

    print('\n    マークの追加、削除を終了しました\n\n')
    set_msg('マークの追加、削除を終了しました')


#------------------------------------------------------------
# (参考)寸法を追加、削除する 
#------------------------------------------------------------
#def add_kk(seg):
#    geom = seg.getGeom() # Segmentのデーター構造オブジェクト
#    geom_nm = geom.ToString()
#    if geom_nm.find('Dim') > -1:   # 寸法
#        opt = SxOptDimEdit()      # 寸法線編集実行オプションクラス optは継承されない
#        opt = None                # これで継承される 
        
        # dimtext.dimval_type = None

#        ref = geom.txtinfo.val_refer     # (参考）
#        if ref == False:      # ()無し
#            geom.txtinfo.val_refer = True
#        elif ref == True:
#            geom.txtinfo.val_refer = False
        #print(opt.round)
#        seg.editDimText(geom.txtinfo,opt)
#    else: print('\n  寸法ではありません\007')

#------------------------------------------------------------
# 大きなかっこでくくる 21.3.19
#------------------------------------------------------------
def add_kk(seg,thm):
    geom = seg.getGeom() # Segmentのデーター構造オブジェクト
    geom_nm = geom.ToString()
    #print(geom_nm)
    #ss = str(thm) + ')'  
    if geom_nm.find('Dim') > -1:   # 寸法
        opt = SxOptDimEdit()      # 寸法線編集実行オプションクラス optは継承されない
        opt = None                # これで継承される 

        fwd= geom.txtinfo.frontword     # 前置文字
        bwd= geom.txtinfo.backword      # 後置文字

        if fwd == '':                         #前置文字が空
           geom.txtinfo.frontword = '('
           geom.txtinfo.backword = bwd + ')'

        elif fwd != '':
             fwd_1 = fwd[0]                  # 前置文字の一つ目
             fwd_2 = fwd[1:]                 # 前置文字の二つ目以降
             bwd_1 = len(bwd)                # 後置文字の文字数
             bwd_2 = bwd[:bwd_1-1]           # 後置き文字の最後から二つ目
            
             if '（' in fwd :                  # 前置き文字の1つ目が（
                 geom.txtinfo.frontword = fwd_2
                 geom.txtinfo.backword = bwd_2

             elif '（' not in fwd:
                 geom.txtinfo.frontword = '(' + fwd
                 geom.txtinfo.backword = bwd + ')'

        seg.editDimText(geom.txtinfo,opt)
    else:print('\n  寸法ではありません\007')

def push_kk():
    thm = cb_th.get()
    loop = True
    while loop:
        seg = get_seg()
        if seg == False: loop = False; break    # @G0
        #elif seg == None: continue
        elif seg == None: break     # 2020.5.15 終了 
        else: add_kk(seg,thm)

    print('\n    (参考)の追加、削除を終了しました\n\n')
    set_msg('(参考)の追加、削除を終了しました')

             

#------------------------------------------------------------
# フラットバー記号と「引抜」を追加する 21.3.19
#------------------------------------------------------------
def add_fbh(seg,thm):
    geom = seg.getGeom() # Segmentのデーター構造オブジェクト
    geom_nm = geom.ToString()
    #print(geom_nm)
    ss = '×' + str(thm) + '引抜'  
    if geom_nm.find('Dim') > -1:   # 寸法
        opt = SxOptDimEdit()      # 寸法線編集実行オプションクラス optは継承されない
        opt = None                # これで継承される 

        fwd= geom.txtinfo.frontword     # 前置文字
        #print(ref)
        if fwd == '':      # フラットバー記号
            geom.txtinfo.frontword = ''
            geom.txtinfo.backword = ''
            geom.txtinfo.mark3 = 0

        elif fwd == '':
            geom.txtinfo.frontword = ''
            geom.txtinfo.backword = ss

            
        seg.editDimText(geom.txtinfo,opt)
    else: print('\n  寸法ではありません\007')

def push_fbh():
    thm = cb_th.get()
    loop = True
    while loop:
        seg = get_seg()
        if seg == False: loop = False; break    # @G0
        #elif seg == None: continue
        elif seg == None: break     # 2020.5.15 終了 
        else: add_fbh(seg,thm)

    print('\n    FB+引抜の追加、削除を終了しました\n\n')

#------------------------------------------------------------
# フラットバー記号を追加する 
#------------------------------------------------------------
def add_fb(seg,thm):
    geom = seg.getGeom() # Segmentのデーター構造オブジェクト
    geom_nm = geom.ToString()
    #print(geom_nm)
    ss = '×' + str(thm)  
    if geom_nm.find('Dim') > -1:   # 寸法
        opt = SxOptDimEdit()      # 寸法線編集実行オプションクラス optは継承されない
        opt = None                # これで継承される 
        #geom.txtinfo.dimval_type = None     # Noneにしないとopt.round = -1 になってしまう 

        fwd= geom.txtinfo.frontword     # 前置文字
        #print(ref)
        if fwd == '':      # フラットバー記号
            geom.txtinfo.frontword = ''
            geom.txtinfo.backword = ''
            geom.txtinfo.mark3 = 0

        elif fwd == '':
            geom.txtinfo.frontword = ''
            geom.txtinfo.backword = ss

            
        seg.editDimText(geom.txtinfo,opt)
    else: print('\n  寸法ではありません\007')

def push_fb():
    thm = cb_t.get()
    loop = True
    while loop:
        seg = get_seg()
        if seg == False: loop = False; break    # @G0
        #elif seg == None: continue
        elif seg == None: break     # 2020.5.15 終了 
        else: add_fb(seg,thm)

    print('\n    FBの追加、削除を終了しました\n\n')

             

#------------------------------------------------------------
# 寸法の前に個数を追加する 
#------------------------------------------------------------
def add_num(seg,ss_num):
    geom = seg.getGeom() # Segmentのデーター構造オブジェクト
    geom_nm = geom.ToString()
    #print(geom_nm)
    #if geom_nm == "sxnet.SxGeomLengthDim":   # 長さ寸法
    if geom_nm.find('Dim') > -1:   # 寸法
        opt = SxOptDimEdit()      # 寸法線編集実行オプションクラス optは継承されない
        opt = None                # これで継承される 
        #geom.txtinfo.dimval_type = None     # Noneにしないとopt.round = -1 になってしまう 
        #ss_num = str(num)
        num0 = geom.txtinfo.str_num     # 既存の個数

        if num0 == ss_num: geom.txtinfo.str_num = ''
        else: geom.txtinfo.str_num = ss_num
        #geom.txtinfo.str_num = ss_num
            #print( geom.txtinfo.mark3)
            
        seg.editDimText(geom.txtinfo,opt)
    else: print('\n  寸法ではありません\007')

def push_num():
    ss_num = cb_ks.get()
    loop = True
    while loop:
        seg = get_seg()
        if seg == False: loop = False; break    # @G0
        #elif seg == None: continue
        elif seg == None: break     # 2020.5.15 終了 
        else: add_num(seg, ss_num)
 
    print('\n    個数の追加を終了しました\n\n')
    set_msg('個数の追加を終了しました')

#--------------------------------------------------------
#   一般仕上げを呼び出す
#--------------------------------------------------------

def push_ippan():
    #ss = ';MACRO;@ION;LET /ippan/ @go' #これでもOK
    #以下のマクロの記述でもOK　なんとスペースの数も意味があるらしい！！ 
    ss = ';BLOAD'
    ss = ss+';BLOD                                                                           '
    ss = ss+';LOD                                                                            '
    ss = ss+'.FILE /一般仕上げ一覧                          /                                '
    ss = ss+'.DIR1 /C:\ICADSX\parts\部品フォルダ１                                  /        '
    ss = ss+'.DIR2 /                                                                /        '
    ss = ss+'.DIR3 /                                                                /        '
    ss = ss+'.DIR4 /                                                                /        '
    ss = ss+'.LKSMOD /1/                                                                     '
    ss = ss+':                                                                               '

    #ss = ';MACRO;@ION;LET /ippan/ @go'
    SxSys.command(ss,True)

def push_clrt():        # 畠さんの中心線自動回転プログラムを実行
    cmd = 'icd_auto_rotate.exe'
    #result = subprocess.call(cmd,shell=True)
    result = subprocess.Popen(cmd,shell=True)

#-------------------------------------------------------------------------------
# 中心線作図プログラムを実行
#-------------------------------------------------------------------------------
def push_radial_cl():
  cmd = 'py icd_radial_cl.py'
  #result = subprocess.call(cmd,shell=True)
  result = subprocess.Popen(cmd,shell=False)
  #print('\n    中心線作図プログラムを終了しました\n\n')

#-------------------------------------------------------------------------------
# 展開図作成プログラムを実行
#-------------------------------------------------------------------------------
def push_tenkaizu():
    cmd = 'py icd_tenkaizu.py'
    #result = subprocess.call(cmd,shell=True)
    result = subprocess.Popen(cmd,shell=True)
    #print('\n    展開図作成プログラムを終了しました\n\n')
  
#-------------------------------------------------------------------------------
# 公差穴プログラムを追加
#-------------------------------------------------------------------------------
def push_dan_kousa():
  cmd = 'py icd_dim_edit_2.py'
  #result = subprocess.call(cmd,shell=True)
  result = subprocess.Popen(cmd,shell=True)
  #print('\n    長さ穴寸法プログラムを終了しました\n\n')

#------------------------------------------------------------
# はめあいを追加、削除する 
#------------------------------------------------------------
def add_ha(seg):
    geom = seg.getGeom() # Segmentのデーター構造オブジェクト
    geom_nm = geom.ToString()
    if geom_nm.find('Dim') > -1:   # 寸法
        opt = SxOptDimEdit()      # 寸法線編集実行オプションクラス optは継承さない
        opt = None                # これで継承される 
        #geom.txtinfo.dimval_type = None     # Noneにしないとopt.round = -1 になってしまう 
        hameai0 = zen_han.Zen2Han(geom.txtinfo.hmword)     # 既存のはめあい
        hameai = cb_ha.get()      # はめあい文字

        #print(hameai0,hameai)
        if  hameai== hameai0:      # 同じ
            geom.txtinfo.hmword = ''
        else:
            geom.txtinfo.hmword = hameai
        
        seg.editDimText(geom.txtinfo,opt)
    else: print('\n  寸法ではありません\007')

def push_ha():
    loop = True
    while loop:
        seg = get_seg()
        if seg == False: loop = False; break    # @G0
        #elif seg == None: continue
        elif seg == None: break     # 2020.5.15 終了 
        else: add_ha(seg)

    print('\n    はめあいの追加、削除を終了しました\n\n')
    set_msg('はめあいの追加、削除を終了しました')


#------------------------------------------------------------
# 公差を追加、削除する 
#------------------------------------------------------------
def add_ksa(seg):
    print(seg.getInf().type)
    geom = seg.getGeom() # Segmentのデーター構造オブジェクト
    geom_nm = geom.ToString()
    if geom_nm.find('Dim') > -1:   # 寸法
        opt = SxOptDimEdit()      # 寸法線編集実行オプションクラス optは継承されない
        #opt = None                # これで継承される 21.4.5長瀬
        geom.txtinfo.dimval_type = True     # Trueにしないとopt.round を操作できない　21.4.5長瀬
        
        #geom.txtinfo.dimval_type = None     # Noneにしないとopt.round = -1 になってしまう 
        tmp0 = cb_ksa.get()
        tmp = tmp0.split('/')
        if len(tmp) > 1:    #上公差、下公差
            ss_up = tmp[0]; ss_dn = tmp[1]
        else:
            ss_up = tmp0; ss_dn = ''
        
        # 既設公差の取得
        ss_up00 = geom.txtinfo.upper_tolword.replace('°','')      # 上段既存の公差 Space削除
        ss_dn00 = geom.txtinfo.down_tolword.replace('°','')       # 下段既存の公差
        ss_up0 = ss_up00.replace(' ','')      # 上段既存の公差 Space削除
        ss_dn0 = ss_dn00.replace(' ','')       # 下段既存の公差
            
        print(ss_up0)
        #print(ss_up)
        print(ss_dn0)
        #print(ss_dn)

        if  ss_up == ss_up0 and ss_dn == ss_dn0:      # 同じ
            print('同じ公差')
            geom.txtinfo.upper_tolword = ''
            geom.txtinfo.down_tolword = ''

#        elif ss_up == ss_up0:      # 同じ
#            print('同じ公差')
#            geom.txtinfo.upper_tolword = ''
#            geom.txtinfo.down_tolword = ''
          
        
        else:
            if  seg.getInf().type == 26:
                if    ss_dn == "":
                      geom.txtinfo.upper_tolword = ss_up +"^"
                else:
                      geom.txtinfo.upper_tolword = ss_up +"^"
                      geom.txtinfo.down_tolword = ss_dn +"^"
            else:
                geom.txtinfo.upper_tolword = ss_up
                geom.txtinfo.down_tolword = ss_dn
        
        dim0 = geom.diminfo.round     # 既存の桁数
        opt.round = dim0
        opt.dot = True					#小数点を半角に 21.4.5長瀬
        seg.editDimText(geom.txtinfo,opt)
    else: print('\n  寸法ではありません\007')

def push_ksa():
    loop = True
    while loop:
        seg = get_seg()
        if seg == False: loop = False; break    # @G0
        #elif seg == None: continue
        elif seg == None: break     # 2020.5.15 終了 
        else: add_ksa(seg)

    print('\n    公差の追加、削除を終了しました\n\n')
    set_msg('公差の追加、削除を終了しました')



#------------------------------------------------------------
# 寸法の後に文字（キリ）を追加する  後置文字 
#------------------------------------------------------------
def add_backword(seg,back_ss):
    geom = seg.getGeom() # Segmentのデーター構造オブジェクト
    geom_nm = geom.ToString()
    #print(geom_nm)
    #if geom_nm == "sxnet.SxGeomLengthDim":   # 長さ寸法
    if geom_nm.find('Dim') > -1:   # 寸法
        opt = SxOptDimEdit()      # 寸法線編集実行オプションクラス optは継承さない
        #geom.txtinfo.dimval_type = None     # Noneにしないとopt.round = -1 になってしまう 
        #ss_num = str(num)
        back_ss0 = geom.txtinfo.backword     # 既存のbackword

        if back_ss == back_ss0 : geom.txtinfo.backword = ''
        else: geom.txtinfo.backword = back_ss
        #geom.txtinfo.str_num = ss_num
            #print( geom.txtinfo.mark3)
            
        dim0 = geom.diminfo.round     # 既存の桁数
        opt.round = dim0
        opt.dot = True                      #21.3.30 小数点を半角文字にする　長瀬

        seg.editDimText(geom.txtinfo,opt)
    else: print('\n  寸法ではありません\007')

def push_backword():
    back_ss = cb_kt.get()
    loop = True
    while loop:
        seg = get_seg()
        if seg == False: loop = False; break    # @G0
        #elif seg == None: continue
        elif seg == None: break     # 2020.5.15 終了 
        else: add_backword(seg, back_ss)

    print('\n    後置文字の追加を終了しました\n\n')
    set_msg('後置文字の追加を終了しました')


#------------------------------------------------------------
# 寸法の下に文字（円周等分）等を追加する 
#------------------------------------------------------------
def add_downword(seg,down_ss):
    geom = seg.getGeom() # Segmentのデーター構造オブジェクト
    geom_nm = geom.ToString()
    if geom_nm.find('Dim') > -1:   # 寸法
        opt = SxOptDimEdit()      # 寸法線編集実行オプションクラス optは継承されない
        #opt = None                # これで継承される 21.4.5長瀬
        geom.txtinfo.dimval_type = True     # Trueにしないとopt.round を操作できない　21.4.5長瀬
        #geom.txtinfo.dimval_type = None     # Noneにしないとopt.round = -1 になってしまう 
        #opt.round = geom.diminfo.round
        down_ss0 = geom.txtinfo.downword     # 既存のdownword
        print(down_ss0,down_ss)

        if down_ss == down_ss0 : geom.txtinfo.downword = ''
        else: geom.txtinfo.downword = down_ss
            
        dim0 = geom.diminfo.round           #既存の桁数 21.4.5長瀬
        opt.round = dim0		    #21.4.5長瀬
        opt.dot = True                      #21.3.30 小数点を半角文字にする　長瀬
        
        seg.editDimText(geom.txtinfo,opt)
    else: print('\n  寸法ではありません\007')

def push_downword():
    down_ss = zen_han.Han2Zen(cb_st.get())
    loop = True
    while loop:
        seg = get_seg()
        if seg == False: loop = False; break    # @G0
        #elif seg == None: continue
        elif seg == None: break     # 2020.5.15 終了 
        else: add_downword(seg, down_ss)
 
    print('\n    下置文字の追加を終了しました\n\n')
    set_msg('下置文字の追加を終了しました')


#------------------------------------------------------------
# 寸法の桁数(Number od digirs)を編集する
#       参考    SxEntSeg\GetGeomList\GetGeomList.cs
#------------------------------------------------------------
def edit_dim(seg,dim):    # (SxEntSeg, Int)
    geom = seg.getGeom() # Segmentのデーター構造オブジェクト
    geom_nm = geom.ToString()
    #print(geom_nm)
    #if geom_nm == "sxnet.SxGeomLengthDim":   # 長さ寸法
    if geom_nm.find('Dim') > -1:   # 寸法
        opt = SxOptDimEdit()      # 寸法線編集実行オプションクラス optは継承されない
        
        geom.txtinfo.dimval_type = True     # Trueにしないとopt.round を操作できない 
        
        #ss_num = str(num)
        dim0 = geom.diminfo.round     # 既存の桁数
        #if nd == nd0 : opt.round = -1
        #else: opt.roud = nd
        opt.round = dim
        opt.dot = True                      #21.3.30 小数点を半角文字にする 長瀬
        #print(opt.round,nd)     
        seg.editDimText(geom.txtinfo,opt)
    else: print('\n  寸法ではありません\007')

def push_dim():
    ss_dim = cb_dim.get()
    dim = int(ss_dim)         # 整数化
    loop = True
    while loop:
        seg = get_seg()
        if seg == False: loop = False; break    # @G0
        #elif seg == None: continue
        elif seg == None: break     # 2020.5.15 終了 
        else: edit_dim(seg, dim) #; print('桁数変更')

    print('\n    寸法桁数の編集を終了しました\n\n')
    set_msg('寸法桁数の編集を終了しました')



#------------------------------------------------------------
# (個数)タップ寸法注記作成
#------------------------------------------------------------
def make_tks(seg,num):    # 
    #print('"配置点座標と引出し方向を指定してください。')
    pos0 = SxSys.getPos()   # 配置位置
    pos1 = SxSys.getPos()   # 引き出し方向
    
    opt = SxOptDiameterDim()  # 径寸法線作成オプションオブジェクト
    #geom.txtinfo.dimval_type = None     # Noneにしないとopt.round = -1 になってしまう 
    if num > 1:
        opt.str_num = str(num)
    if pos0.x < pos1.x :    # 右向き
        opt.lead_left = False
    else:                   # 左向き
        opt.lead_left = True 
    
    try:
        seg_tmp = SxEntSeg.createDiameterDimLead(seg, pos0, opt)    #仮の寸法作成
    except:
        print('\n    径寸法対象ではありません\007')

        return False

    
    # Segmentの所属するパーツ（実像部品）オブジェクトを作成する！  Note!
    rpart = seg.getRPart()    # セグメントの所属する実像部品を取得する  
    rp_inf = rpart.getInfDetail()
    rp_nm = rp_inf.name
    print(rp_nm)

    if rp_nm.find('M') > -1 and rp_nm.find('×') > -1 and rp_nm.find('-') > -1 : # LHタップx深さ(細目対応)
        #print('タップｘ深さ')
        find_x = rp_nm.find('×')
#        print(find_x)
        find_lh = rp_nm.find('-')
#        print(find_lh)

        if find_x < find_lh :                                                    # 細目左ねじの場合
            idx = rp_nm.index('×')                                              # × 以降の文字を取得
            ss = rp_nm[idx:]
            ss_tmp = ss.split('(')                                               # ( でセパレート
            ss_x_lh = ss_tmp[0]                                                  # ( 以前の文字を入力
            geom = seg_tmp.getGeom()                                             # Segmentのデーター構造オブジェクト
            geom.txtinfo.backword = ss_x_lh                                      # ピッチとLHと深さを付加
            geom.txtinfo.mark3 = 6                                               # Mを付加
            seg_tmp.editDimText(geom.txtinfo,None)                               # optは省略

        elif find_x > find_lh :                                                  # 非貫通左ねじの場合
            idx = rp_nm.index('-')                                               # - 以降の文字を取得
            ss = rp_nm[idx:]
            ss_tmp = ss.split('(')                                               # ( でセパレート
            ss_lh_x = ss_tmp[0]                                                  # ( 以前の文字を入力
            geom = seg_tmp.getGeom()                                             # Segmentのデーター構造オブジェクト
            geom.txtinfo.backword = ss_lh_x                                      # LHと深さを付加
            geom.txtinfo.mark3 = 6                                               # Mを付加
            seg_tmp.editDimText(geom.txtinfo,None)                               # optは省略

    elif rp_nm.find('M') > -1 and rp_nm.find('×') > -1 :                        # タップx深さ
        #print('タップｘ深さ')
        find_m = rp_nm.find('×')
        print(find_m)
        idx = rp_nm.index('×')
        ss = rp_nm[idx:]
        geom = seg_tmp.getGeom()                                                 # Segmentのデーター構造オブジェクト
        geom.txtinfo.backword = ss
        geom.txtinfo.mark3 = 6                                                   # Mを付加
        seg_tmp.editDimText(geom.txtinfo,None)                                   # optは省略

    elif rp_nm.find('M') > -1 and rp_nm.find('-') > -1 :                         # 左ねじ
        idx = rp_nm.index('-')
        ss = rp_nm[idx:]                                                         # - 以降の文字列を取得
        ss_tmp = ss.split('(')                                                   # / でセパレート
        ss_lh = ss_tmp[0]                                                        # 上下公差値を取得
        geom = seg_tmp.getGeom()                                                 # Segmentのデーター構造オブジェクト
        geom.txtinfo.hmword = ss_lh                                              # -LHを入力
        geom.txtinfo.mark3 = 6                                                   # Mマーク追加
        seg_tmp.editDimText(geom.txtinfo,None)                                   # optは省略

    elif rp_nm.find('M') > -1:        # タップ
        #print('タップ')
        mk_no = 6                   # 'Ｍ'
        add_mark(seg_tmp, mk_no)           # マーク追加

    elif rp_nm.find('ｷﾘφ') > -1:  # ザグリ穴
        #print('ザグリ')
        idx = rp_nm.index('ｷﾘ'); ss = rp_nm[idx:]
        add_backword(seg_tmp, ss)  # 後置文字追加

    elif rp_nm.find('キリφ') > -1: # ザグリ穴
        idx = rp_nm.index('キリ'); ss = rp_nm[idx:]
        add_backword(seg_tmp, ss)  # 後置文字追加

    elif rp_nm.find('ｷﾘ') > -1 :     # ｷﾘ穴ｘ深さ
        idx = rp_nm.index('ｷﾘ'); ss = rp_nm[idx:]
        add_backword(seg_tmp, ss)  # 後置文字追加
    elif rp_nm.find('キリ') > -1 :     # キリ穴ｘ深さ
        idx = rp_nm.index('キリ'); ss = rp_nm[idx:]
        add_backword(seg_tmp, ss)  # 後置文字追加

    elif rp_nm.find('キリ') > -1 :     # サラもみ
        idx = rp_nm.index('キリ'); ss = rp_nm[idx:]
        add_backword(seg_tmp, ss)  # 後置文字追加
    
    elif rp_nm.find('キリ') > -1:     # キリ穴
        #print('キリ穴')
        add_backword(seg_tmp, 'キリ')  # 後置文字追加

    elif rp_nm.find('リーマ') > -1:     # リーマ穴
        #print('キリ穴')
        add_backword(seg_tmp, 'リーマ')  # 後置文字追加

# 21.9.3 N長瀬 畠さんの公差穴対応

    elif rp_nm.find('φ') > -1 and rp_nm.find('_') > -1 and rp_nm.find('/') > -1:  # 二段公差穴
        idx = rp_nm.index('_')
        ss = rp_nm[idx+1:]                                                         # '_' 以降の文字列を取得
        geom = seg_tmp.getGeom()                                                   # Segmentのデーター構造オブジェクト
        ss_tmp = ss.split('/')                                                     # / でセパレート
        ss_up = ss_tmp[0]; ss_dn = ss_tmp[1]                                       # 上下公差値を取得
        geom.txtinfo.upper_tolword = ss_up                                         # 上公差値を入力
        geom.txtinfo.down_tolword = ss_dn                                          # 下公差値を入力
        geom.txtinfo.mark3 = 1                                                     # φマーク追加
        seg_tmp.editDimText(geom.txtinfo,None)                                     # optは省略

    elif rp_nm.find('φ') > -1 and rp_nm.find('_') > -1 and rp_nm.find('±') > -1: # ±公差穴
        idx = rp_nm.index('_')
        ss = rp_nm[idx+1:]                                                         # '_' 以降の文字列を取得
        geom = seg_tmp.getGeom()                                                   # Segmentのデーター構造オブジェクト
        geom.txtinfo.upper_tolword = ss                                            # 公差値を入力
        geom.txtinfo.mark3 = 1                                                     # φマーク追加
        seg_tmp.editDimText(geom.txtinfo,None)                                     # optは省略

    elif rp_nm.find('φ') > -1 and rp_nm.find('_') > -1 :                          # はめあい公差穴
        idx = rp_nm.index('_')
        ss = rp_nm[idx+1:]                                                         # '_' 以降の文字列を取得
        geom = seg_tmp.getGeom()                                                   # Segmentのデーター構造オブジェクト
        geom.txtinfo.hmword = ss                                                   # はめあい公差を入力
        geom.txtinfo.mark3 = 1                                                     # φマーク追加
        seg_tmp.editDimText(geom.txtinfo,None)                                     # optは省略

    elif rp_nm.find('Tr') > -1 :                                                   # 台形ねじ
        idx = rp_nm.index('×')
        ss = rp_nm[idx:]                                                           # '×' 以降の文字列を取得
        geom = seg_tmp.getGeom()                                                   # Segmentのデーター構造オブジェクト
        geom.txtinfo.mark3 = SxDimValueAtr.ATRDIM_MARK3_OPT                        # 21.9.6 堀内さんに教えて頂いた。
        geom.txtinfo.opt_word = "Tr"                                               # 21.9.6 堀内さんに教えて頂き、記号欄に'Tr'入力可
        geom.txtinfo.backword = ss                                                 # ピッチを記入
        seg_tmp.editDimText(geom.txtinfo,None)                                     # optは省略

# 21.5.15 N長瀬 レーザー加工穴でのφ追加
    elif rp_nm.find('φ') > -1:                                                    # レーザー加工穴
        mk_no = 1                                                                  # 'φ'
        add_mark(seg_tmp, mk_no)                                                   # マーク追加

# 22.12.5 N長瀬 ガスネジ対応
    elif rp_nm.find('Rc') > -1 or rp_nm.find('Rp') > -1 or rp_nm.find('G') > -1 :                                                   # 台形ねじ
        ss = rp_nm
        geom = seg_tmp.getGeom()                                                   # Segmentのデーター構造オブジェクト
        geom.txtinfo.dimval_type = False
        geom.txtinfo.valword = ss
        seg_tmp.editDimText(geom.txtinfo,None) 

def push_tks():
    ss_num = cb_tks.get()
    num = int(ss_num)         # 整数化
    loop = True
    while loop:
        seg = get_seg()
        if seg == False: loop = False; break    # @G0
        #elif seg == None: continue
        elif seg == None: break     # 2020.5.15 終了 
        else: tmp = make_tks(seg, num)
 

    print('\n    タップ寸法注記作成を終了しました\n\n')
    set_msg('タップ寸法注記作成を終了しました')
    
#------------------------------------------------------------
# 長さ寸法の公差穴
#------------------------------------------------------------

def make_len_ksa(seg,num):    # 
    #print('"配置点座標と引出し方向を指定してください。')
    line0 = get_seg()  # 配置位置
    line1 = get_seg()   # 引き出し方向
    pos0 = SxSys.getPos()   # 引き出し方向
    
    opt = SxOptLengthDim()  # 径寸法線作成オプションオブジェクト
    #geom.txtinfo.dimval_type = None     # Noneにしないとopt.round = -1 になってしまう 
    
    try:
        seg_tmp = SxEntSeg.createLengthDimStd2D(line0,line1, pos0, opt)    #仮の寸法作成
    except:
        print('\n    径寸法対象ではありません\007')

        return False

    
    # Segmentの所属するパーツ（実像部品）オブジェクトを作成する！  Note!
    rpart = seg.getRPart()    # セグメントの所属する実像部品を取得する  
    rp_inf = rpart.getInfDetail()
    rp_nm = rp_inf.name
    print(rp_nm)

    if rp_nm.find('φ') > -1 and rp_nm.find('_') > -1 and rp_nm.find('/') > -1:  # 二段公差穴
        idx = rp_nm.index('_')
        ss = rp_nm[idx+1:]                                                         # '_' 以降の文字列を取得
        geom = seg_tmp.getGeom()                                                   # Segmentのデーター構造オブジェクト
        ss_tmp = ss.split('/')                                                     # / でセパレート
        ss_up = ss_tmp[0]; ss_dn = ss_tmp[1]                                       # 上下公差値を取得
        geom.txtinfo.upper_tolword = ss_up                                         # 上公差値を入力
        geom.txtinfo.down_tolword = ss_dn                                          # 下公差値を入力
        geom.txtinfo.mark3 = 1                                                     # φマーク追加
        seg_tmp.editDimText(geom.txtinfo,None)                                     # optは省略

    elif rp_nm.find('φ') > -1 and rp_nm.find('_') > -1 and rp_nm.find('±') > -1: # ±公差穴
        idx = rp_nm.index('_')
        ss = rp_nm[idx+1:]                                                         # '_' 以降の文字列を取得
        geom = seg_tmp.getGeom()                                                   # Segmentのデーター構造オブジェクト
        geom.txtinfo.upper_tolword = ss                                            # 公差値を入力
        geom.txtinfo.mark3 = 1                                                     # φマーク追加
        seg_tmp.editDimText(geom.txtinfo,None)                                     # optは省略

    elif rp_nm.find('φ') > -1 and rp_nm.find('_') > -1 :                          # はめあい公差穴
        idx = rp_nm.index('_')
        ss = rp_nm[idx+1:]                                                         # '_' 以降の文字列を取得
        geom = seg_tmp.getGeom()                                                   # Segmentのデーター構造オブジェクト
        geom.txtinfo.hmword = ss                                                   # はめあい公差を入力
        geom.txtinfo.mark3 = 1                                                     # φマーク追加
        seg_tmp.editDimText(geom.txtinfo,None)


def push_mlk():
    ss_num = cb_tks.get()
    num = int(ss_num)         # 整数化
    loop = True
    while loop:
        seg = get_seg()
        if seg == False: loop = False; break    # @G0
        #elif seg == None: continue
        elif seg == None: break     # 2020.5.15 終了 
        else: tmp = make_len_ksa(seg, num)
 

    print('\n    タップ寸法注記作成を終了しました\n\n')
    set_msg('タップ寸法注記作成を終了しました')

#------------------------------------------------------------
# 図枠、表題欄の作成
#       参考   
#------------------------------------------------------------
def push_zwk():
    ss_size = e_zwk.get()

    print('\n    図枠、表題欄を作成しました\n\n')


#--------------------------------------
#   半角、倍角変換  2021.1.10 追加
#--------------------------------------
def push_han_abi():
    loop = True
    while loop:
        seg = get_seg()
        if seg == False: loop = False; break    # @G0
        elif seg == None: break      
        else: han_abi(seg)
 
    print('\n    半角、倍角変換を終了しました\n\n')
    set_msg('半角、倍角変換を終了しました')

def han_abi(seg):    
    #seg = get_seg()
    geom = seg.getGeom()
    geom_nm = geom.ToString()
    
    if geom_nm.find('SxGeomText') > -1 or geom_nm.find('SxGeomLabel') > -1:   # Text or Label Geometory なら
        #print(geom.txt[0])
        nl = len(geom.txt)
        text = []
        for ss0 in geom.txt:
            ss = zen_han.Han2Zen(ss0, zen_han.EISU)
            #print(ss)
            ss = ss.replace('{Ｕ','{U'); ss = ss.replace('Ｕ}','U}')
            ss = ss.replace('{Ｓ','{S'); ss = ss.replace('Ｓ}','S}')
            ss = ss.replace('{Ｆ','{F'); ss = ss.replace('Ｆ}','F}')
            ss = ss.replace('{Ｔ','{T'); ss = ss.replace('Ｔ}','T}')
            ss = ss.replace('{Ａ','{A'); ss = ss.replace('Ａ}','A}')
            ss = ss.replace('{Ｅ','{E'); ss = ss.replace('Ｅ}','E}')
            #print(ss)
            text.append(ss)   # 英数字だけを倍角 
            #text.append(zen_han.Han2Zen(ss,zen_han.DIGIT))   # 数値だけを倍角 
            #text.append(zen_han.Han2Zen(ss))
                    
        seg.editText(text)
    else:
        print('\n   文字列か注記を選択してください \007\n')

#------------------------------------------------------------
# (R)寸法に変更する  2021.4.24 長瀬追加
#------------------------------------------------------------
def chg_rr(seg):
    geom = seg.getGeom()                        # Segmentのデーター構造オブジェクト
    geom_nm = geom.ToString()
    if geom_nm.find('Dim') > -1:                # 寸法
        opt = SxOptDimEdit()                    # 寸法線編集実行オプションクラス optは継承されない
        opt = None                              # これで継承される 

 #       ref = geom.txtinfo.val_refer           # (参考）
        div = geom.txtinfo.dimval_type          # 実寸偽寸
        if div == True:                         # 実寸
            geom.txtinfo.dimval_type = False
            geom.txtinfo.valword = ""
            geom.txtinfo.val_refer = True
        elif div == False:
            geom.txtinfo.dimval_type = True
            geom.txtinfo.val_refer = False
         #print(opt.round)
#        geom.txtinfo.dimval_type = False
#        geom.txtinfo.valword = ""
#        geom.txtinfo.val_refer = True
        seg.editDimText(geom.txtinfo,opt)
    else: print('\n  寸法ではありません\007')

def push_rr():
    loop = True
    while loop:
        seg = get_seg()
        if seg == False: loop = False; break    # @G0
        #elif seg == None: continue
        elif seg == None: break     # 2020.5.15 終了 
        else: chg_rr(seg)

    print('\n    (R)寸法への変更を終了しました\n\n')
    set_msg('(R)寸法への変更を終了しました')

#------------------------------------------------------------
# 円筒カム寸法の下に外周角度を追加する   2021.4.24 長瀬追加
#------------------------------------------------------------
def add_downdeg(seg,down_deg):
    geom = seg.getGeom()                                    # Segmentのデーター構造オブジェクト
    geom_nm = geom.ToString()
    dim0 = geom.diminfo.round                               #既存の桁数 21.6.5長瀬
    if geom_nm.find('Dim') > -1:                            # 寸法
        opt = SxOptDimEdit()                                # 寸法線編集実行オプションクラス optは継承される
#        geom.txtinfo.dimval_type = None                     # Noneにしないとopt.round = -1 になってしまう 
        d_len = geom.txtinfo.dist1
#        print(d_len)                                       #寸法値
        down_sss = d_len / down_deg / math.pi * 360         #展開長計算
        down_ssss = str('{:.3f}'.format(down_sss)) + "°"   #3桁化+°
#        print(down_ssss)                                   #外周角度
        geom.txtinfo.downword = str(down_ssss)
        geom.txtinfo.val_refer = True                       #21.05.15 カッコをON
        geom.txtinfo.dimval_type = True                     #21.05.15 寸法値を実寸
        opt.round = dim0		                    #21.06.05 既存の桁数長瀬
        opt.dot = True                                      #21.03.30 小数点を半角文字にする　長瀬
        seg.editDimText(geom.txtinfo,opt)
#    else: print('\n  寸法ではありません\007')

def push_downdeg():
#    down_ss = zen_han.Han2Zen(cb_st.get())
    down_deg = int(cb_dg.get())
    loop = True
    while loop:
        seg = get_seg()
        if seg == False: loop = False; break    # @G0
        #elif seg == None: continue
        elif seg == None: break     # 2020.5.15 終了 
        else: add_downdeg(seg, down_deg)
 
    print('\n    外周角度の追加を終了しました\n\n')
    set_msg('外周角度の追加を終了しました')

#------------------------------------------------------------
# ２×２×Ｍ６等大きなくくりの個数追加
# 参考⇒寸法の前に個数を追加する
# 21.6.5 長瀬
#------------------------------------------------------------

def add_dnum(seg,ss_dnum):
    geom = seg.getGeom() # Segmentのデーター構造オブジェクト
    geom_nm = geom.ToString()

    if geom_nm.find('Dim') > -1:   # 寸法
        opt = SxOptDimEdit()      # 寸法線編集実行オプションクラス optは継承されない
        opt = None                # これで継承される 

        fwd= geom.txtinfo.frontword     # 前置文字

#カッコの時の考慮は 21.06.05 長瀬挫折
#        if '（' in fwd :                         #前置文字に（が含まれる場合
#          geom.txtinfo.frontword = '(' + ss_dnum + '×'
#        elif '（' not in fwd:
#          geom.txtinfo.frontword = ss_dnum + '×'

        geom.txtinfo.frontword = ss_dnum + '×' +fwd
        seg.editDimText(geom.txtinfo,opt)
    else:print('\n  寸法ではありません\007')

def push_dnum():
    thm = cb_dks.get()
    loop = True
    while loop:
        seg = get_seg()
        if seg == False: loop = False; break    # @G0
        #elif seg == None: continue
        elif seg == None: break     # 2020.5.15 終了 
        else: add_dnum(seg,thm)

    print('\n    大個数の追加を終了しました\n\n')
    set_msg('大個数の追加を終了しました')

def push_srs_ang():
    cmd = 'icd_series_ang_dim.py'
    result = subprocess.Popen(cmd,shell=True)

#------------------------------------------------------------
# 寸法装飾リセット   2021.6.05 長瀬追加
#------------------------------------------------------------
def reset_dim(seg):
    geom = seg.getGeom()                                    # Segmentのデーター構造オブジェクト
    geom_nm = geom.ToString()
    if geom_nm.find('Dim') > -1:                            # 寸法
        opt = SxOptDimEdit()                                # 寸法線編集実行オプションクラス optは継承される
#        SxDimValueAtr.ATRDIM_MARK_NONE
        geom.txtinfo.mark3 = 0                          # マーク削除
        geom.txtinfo.str_num = ''                           # 個数を空
        geom.txtinfo.frontword = ''                         # 前置文字を空
        geom.txtinfo.backword = ''                          # 後置き文字を空
        geom.txtinfo.downword = ''                          # 下置き文字を空
        geom.txtinfo.upper_tolword = ''                     # 上公差を抹消
        geom.txtinfo.down_tolword = ''                      # 下公差を抹消
        geom.txtinfo.hmword = ''                            # はめあいを空
        geom.txtinfo.val_refer = False
        geom.txtinfo.dimval_type = True                     # 寸法値を実寸
        opt.round = -3  		                    # 寸法桁数を-3
        opt.dot = True                                      # 小数点を半角文字にする

        seg.editDimText(geom.txtinfo,opt)
#    else: print('\n  寸法ではありません\007')

def push_reset_dim():
    loop = True
    while loop:
        seg = get_seg()
        if seg == False: loop = False; break    # @G0
        #elif seg == None: continue
        elif seg == None: break     # 2020.5.15 終了 
        else: reset_dim(seg)

#--------------------------------------
#   文字囲み追加  2021.11.23 長瀬追加
#--------------------------------------
def push_ad_kakomi():
    loop = True
    while loop:
        seg = get_seg()
        if seg == False: loop = False; break    # @G0
        elif seg == None: break      
        else: ad_kakomi(seg)
 
    print('\n    文字囲み追加を終了しました\n\n')
    set_msg('文字囲み追加を終了しました')

def ad_kakomi(seg):    
    #seg = get_seg()
    geom = seg.getGeom()
    geom_nm = geom.ToString()
    
    if geom_nm.find('SxGeomText') > -1 or geom_nm.find('SxGeomLabel') > -1:   # Text or Label Geometory なら
        #print(geom.txt[0])
        #nl = len(geom.txt)
        text = []                                 #文字列のリストを作る（喜多さんに教えて頂いた
        for ss0 in geom.txt:
            if ss0 == '':   break                 #これが無いと空白文字がおかしい（喜多さんにやって頂いた
            elif ss0 == ' ': continue             #これも無いと空白文字がおかしい（喜多さんにやって頂いた
            if ss0.find('{F') > -1:               #選択した文字が囲み文字の場合
              ss_tmp = ss0.replace('{F','F}')     #囲み文字記号を消す
              ss = ss_tmp
            elif ss0.find('{U') > -1:
              ss_tmp = ss0.replace('{U','U}')
              ss = "{F" + ss_tmp + "F}"
            elif ss0.find('{S') > -1:
              ss_tmp = ss0.replace('{S','S}')
              ss = "{F" + ss_tmp + "F}"
            elif ss0.find('{T') > -1:
              ss_tmp = ss0.replace('{T','T}')
              ss = "{F" + ss_tmp + "F}"
            elif ss0.find('{A') > -1:
              ss_tmp = ss0.replace('{A','A}')
              ss = "{F" + ss_tmp + "F}"
            elif ss0.find('{E') > -1:
              ss_tmp = ss0.replace('{E','E}')
              ss = "{F" + ss_tmp + "F}"
            else: ss = "{F" + ss0 + "F}"
            print(ss)
            text.append(ss)
                    
        seg.editText(text)
    else:
        print('\n   文字列か注記を選択してください \007\n')

#--------------------------------------
#   文字下線追加  2021.11.23 長瀬追加
#--------------------------------------
def push_ad_ubar():
    loop = True
    while loop:
        seg = get_seg()
        if seg == False: loop = False; break    # @G0
        elif seg == None: break      
        else: ad_ubar(seg)
 
    print('\n    文字下線追加を終了しました\n\n')
    set_msg('文字下線追加を終了しました')

def ad_ubar(seg):    
    #seg = get_seg()
    geom = seg.getGeom()
    geom_nm = geom.ToString()
    
    if geom_nm.find('SxGeomText') > -1 or geom_nm.find('SxGeomLabel') > -1:   # Text or Label Geometory なら
        #print(geom.txt[0])
        #nl = len(geom.txt)
        text = []
        for ss0 in geom.txt:
            if ss0 == '':   break
            elif ss0 == ' ': continue
            if ss0.find('{U') > -1:
              ss_tmp = ss0.replace('{U','U}')
              ss = ss_tmp
            elif ss0.find('{F') > -1:
              ss_tmp = ss0.replace('{F','F}')
              ss = "{U" + ss_tmp + "U}"
            elif ss0.find('{S') > -1:
              ss_tmp = ss0.replace('{S','S}')
              ss = "{U" + ss_tmp + "U}"
            elif ss0.find('{T') > -1:
              ss_tmp = ss0.replace('{T','T}')
              ss = "{U" + ss_tmp + "U}"
            elif ss0.find('{A') > -1:
              ss_tmp = ss0.replace('{A','A}')
              ss = "{U" + ss_tmp + "U}"
            elif ss0.find('{E') > -1:
              ss_tmp = ss0.replace('{E','E}')
              ss = "{U" + ss_tmp + "U}"
            else: ss = "{U" + ss0 + "U}"
            print(ss)
            text.append(ss)
                    
        seg.editText(text)
    else:
        print('\n   文字列か注記を選択してください \007\n')

#------------------------------------------------------------
# 実寸値に変更する  2022.6.8 長瀬追加
#------------------------------------------------------------
def chg_t(seg):
    geom = seg.getGeom()                        # Segmentのデーター構造オブジェクト
    geom_nm = geom.ToString()
    if geom_nm.find('Dim') > -1:                # 寸法
        opt = SxOptDimEdit()                    # 寸法線編集実行オプションクラス optは継承されない
        opt = None                              # これで継承される 

        div = geom.txtinfo.dimval_type          # 実寸偽寸
        if  div == False:
            geom.txtinfo.dimval_type = True

        seg.editDimText(geom.txtinfo,opt)
    else: print('\n  寸法ではありません\007')

def push_t():
    loop = True
    while loop:
        seg = get_seg()
        if seg == False: loop = False; break    # @G0
        #elif seg == None: continue
        elif seg == None: break     # 2020.5.15 終了 
        else: chg_t(seg)

    print('\n    実寸法への変更を終了しました\n\n')
    set_msg('実寸法への変更を終了しました')

#------------------------------------------------------------
# 200レイヤ  2022.6.8 長瀬追加
#------------------------------------------------------------
def chg_t(seg):
    geom = seg.getGeom()                        # Segmentのデーター構造オブジェクト
    geom_nm = geom.ToString()
    if geom_nm.find('Dim') > -1:                # 寸法
        opt = SxOptDimEdit()                    # 寸法線編集実行オプションクラス optは継承されない
        opt = None                              # これで継承される 

        div = geom.txtinfo.dimval_type          # 実寸偽寸
        if  div == False:
            geom.txtinfo.dimval_type = True

        seg.editDimText(geom.txtinfo,opt)
    else: print('\n  寸法ではありません\007')

def push_lay():
    loop = True
    while loop:
        seg = get_seg()
        if seg == False: loop = False; break    # @G0
        #elif seg == None: continue
        elif seg == None: break     # 2020.5.15 終了 
        else: chg_t(seg)

    print('\n    実寸法への変更を終了しました\n\n')
    set_msg('実寸法への変更を終了しました')

##
def push_lay200_of():
    SxSys.setDispLayer(200, False)      #レイヤの非表示

def push_lay200_on():
    SxSys.setSearchLayer(200, True)     # レイヤの表示,Seachにしないと検索と表示がONにならない
    ###
    #boolean は True or False

#------------------------------------------------------------
# iCADコマンド追加  2023.2.10 長瀬追加
#------------------------------------------------------------

def dim_ya_arw():
    ss = ';DRFEDT;TMARK;TMDL;BAR'
    SxSys.command(ss,False)
    
def dim_ya_maru():
    ss = ';DRFEDT;TMARK;TMDL;DOT'
    SxSys.command(ss,False)

def dim_ya_non():
    ss = ';DRFEDT;TMARK;TMDL;NMK'
    SxSys.command(ss,False)

def dim_ya_mir():
    ss = ';DRFEDT;TMARK;MIR'
    SxSys.command(ss,False)

def txt_size_2():
    ss = ';DRFEDT;CDMLOC;AATR;TBL2'
    SxSys.command(ss,False)

def dim_real():
    ss = ';DRFEDT;TXT;HRUL;ERST'
    SxSys.command(ss,False)

def dim_gensize():
    ss = ';CDMLOC;ASIZ'
    SxSys.command(ss,False)

def dim_genzoku():
    ss = ';CDMLOC;AATR;TBLD'
    SxSys.command(ss,False)

def chg_ud():
    ss = ';DRFEDT;PLA;MOV;MIRV'
    SxSys.command(ss,False)

def chg_rl():
    ss = ';DRFEDT;PLA;MOV;MIR'
    SxSys.command(ss,False)

def dim_trm():
    ss = ';DRFEDT;SUBLIN;NTDR'
    SxSys.command(ss,False)

def dim_drm():
    ss = ';DRFEDT;SUBLIN;FZJH'
    SxSys.command(ss,False)

def dim_auto():
    ss = ';DIMAPL;DRFEDT;PLA;AUTO'
    SxSys.command(ss,False)

#--------------------------------------------------------------------------------
#   寸法編集
#--------------------------------------------------------------------------------
def push_txt_chg():
  cmd = 'py icd_txt_chg.py '
  result = subprocess.Popen(cmd,shell=True)



# 終了時の処理(画面サイズ,位置保存)
def on_closing():
    ss_geom = root.geometry() 
    mmd.save_geometry(save_fn_geom, ss_geom)
    root.destroy()




#------------------------------------------------------------
#   Commboboxの文字情報読み込み
#------------------------------------------------------------
if len(sys.argv) < 2:   #引き数無し
    fn = 'icd_dim_edit.txt'
elif len(sys.argv) == 2:    # 引き数１個 
    fn = sys.argv[1]
    
fp = codecs.open(fn,'r','utf-8')    # 文字コードを指定して読み込み
lines0 = fp.readlines()
fp.close()
lines = []
for line in lines0:
    tmp = line.rstrip()     
    lines.append(tmp)       # 行末の改行を削除

#print(lines)

idx = lines.index('#記号')
ss_cb_mk = lines[idx+1].split(',')
#print(ss_cb_mk)

idx = lines.index('#引抜+厚み')
ss_cb_th = lines[idx+1].split(',')

idx = lines.index('#厚み')
ss_cb_t = lines[idx+1].split(',')

idx = lines.index('#個数')
ss_cb_ks = lines[idx+1].split(',')

idx = lines.index('#大個数')
ss_cb_dks = lines[idx+1].split(',')

idx = lines.index('#はめあい')
ss_cb_ha = lines[idx+1].split(',')

idx = lines.index('#公差')
ss_cb_ksa = lines[idx+1].split(',')

idx = lines.index('#後置文字')
ss_cb_kt = lines[idx+1].split(',')

idx = lines.index('#下置文字')
ss_cb_st = lines[idx+1].split(',')

idx = lines.index('#外径入力')
ss_cb_dg = lines[idx+1].split(',')

idx = lines.index('#寸法桁数')
ss_cb_dim = lines[idx+1].split(',')

idx = lines.index('#タップ、キリ個数')
ss_cb_tks = lines[idx+1].split(',')

idx = lines.index('#図枠')
ss_cb_zwk = lines[idx+1].split(',')



#************************************
# 画面設定、ボタン等の部品配置
#************************************

root = tk.Tk()
root.attributes("-topmost", True)    # 常に前面に表示
root.configure(bg='RoyalBlue4')
root.title('寸法編集 Ver.1.01')   #タイトル
###画面サイズ、位置再現のための起動時の処理
nl = 13
fn = os.path.basename(__file__)     # get_place.py   
(tmp, ext) = os.path.splitext(fn)   # (get_place, py)
save_fn_geom = '%s.ini' % tmp
ss_geom = mmd.read_geometry(save_fn_geom)
if ss_geom == None:
    ss_geom = '300x%d+1100+0' % (nl*35)
    
root.geometry(ss_geom)

#root.geometry('250x460+1100+0')
# blue  red  khaki3  cyan  white

btn_bcol = 'grey21'     #ボタン背景色
btn_tcol = 'white'      #ボタン文字色
label_bcol = 'khaki3'   #ラベル背景色
label_tcol = 'black'   #ラベル文字色
e_bcol = 'khaki4'

dx = 50;  dy = 35
x00 = 5; x01 =x00+dx; y00 = 5

#----------------------------------------------------------------
ss = 'ヘルプ'; num = 0
#----------------------------------------------------------------
btn_help = tk.Button(root,text = ss,command = push_help,bg=btn_bcol,fg=btn_tcol) #ボタンの作成
btn_help.place(x=x00+150,y=y00+num*dy)





def push_cb_edit():
  cmd = 'notepad '+ dim_edit_fn
  #result = subprocess.call(cmd,shell=True)
  result = subprocess.Popen(cmd,shell=True)

#---------------------------------------------------
ss = 'ﾘｾｯﾄ'; num = 0
#---------------------------------------------------
btn = tk.Button(root,text = ss,command = push_reset_dim,bg='orange',fg='black') #ボタンの作成
btn.place(x=x00+200,y=y00+num*dy)

#---------------------------------------------------
ss = '＜'; num = 0
#---------------------------------------------------
btn_exe = tk.Button(root,text = ss,command = dim_ya_arw, bg='gray',fg=btn_tcol) #ボタンの作成
btn_exe.place(x=x00+250,y=y00+num*dy)

#---------------------------------------------------
ss = ' ・ '; num = 0
#---------------------------------------------------
btn_exe = tk.Button(root,text = ss,command = dim_ya_maru, bg='gray',fg=btn_tcol) #ボタンの作成
btn_exe.place(x=x00+280,y=y00+num*dy)

#---------------------------------------------------
ss = '無'; num = 0
#---------------------------------------------------
btn_exe = tk.Button(root,text = ss,command = dim_ya_non, bg='gray',fg=btn_tcol) #ボタンの作成
btn_exe.place(x=x00+310,y=y00+num*dy)

#---------------------------------------------------
ss = '実寸化'; num = 1
#---------------------------------------------------
btn_exe = tk.Button(root,text = ss,command = dim_real, bg='brown',fg=btn_tcol) #ボタンの作成
btn_exe.place(x=x00+250,y=y00+num*dy)

#---------------------------------------------------
ss = '矢反'; num = 1
#---------------------------------------------------
btn_exe = tk.Button(root,text = ss,command = dim_ya_mir, bg='gray',fg=btn_tcol) #ボタンの作成
btn_exe.place(x=x00+300,y=y00+num*dy)

#---------------------------------------------------
ss = '現尺度'; num = 2
#---------------------------------------------------
btn_exe = tk.Button(root,text = ss,command = dim_gensize, bg='brown',fg=btn_tcol) #ボタンの作成
btn_exe.place(x=x00+250,y=y00+num*dy)

#---------------------------------------------------
ss = '字５'; num = 2
#---------------------------------------------------
btn_exe = tk.Button(root,text = ss,command = txt_size_2, bg='brown',fg=btn_tcol) #ボタンの作成
btn_exe.place(x=x00+300,y=y00+num*dy)

#---------------------------------------------------
ss = '現属性'; num = 3
#---------------------------------------------------
btn_exe = tk.Button(root,text = ss,command = dim_genzoku, bg='brown',fg=btn_tcol) #ボタンの作成
btn_exe.place(x=x00+250,y=y00+num*dy)

#---------------------------------------------------
ss = '自動'; num = 3
#---------------------------------------------------
btn_exe = tk.Button(root,text = ss,command = dim_auto, bg='brown',fg=btn_tcol) #ボタンの作成
btn_exe.place(x=x00+300,y=y00+num*dy)

#---------------------------------------------------
ss = '縦反'; num = 4
#---------------------------------------------------
btn_exe = tk.Button(root,text = ss,command = chg_ud, bg='darkslategray',fg=btn_tcol) #ボタンの作成
btn_exe.place(x=x00+250,y=y00+num*dy)

#---------------------------------------------------
ss = '横反'; num = 4
#---------------------------------------------------
btn_exe = tk.Button(root,text = ss,command = chg_rl, bg='darkslategray',fg=btn_tcol) #ボタンの作成
btn_exe.place(x=x00+300,y=y00+num*dy)

#---------------------------------------------------
ss = '打抜'; num = 5
#---------------------------------------------------
btn_exe = tk.Button(root,text = ss,command = dim_trm, bg='darkslategray',fg=btn_tcol) #ボタンの作成
btn_exe.place(x=x00+250,y=y00+num*dy)

#---------------------------------------------------
ss = '結合'; num = 5
#---------------------------------------------------
btn_exe = tk.Button(root,text = ss,command = dim_drm, bg='darkslategray',fg=btn_tcol) #ボタンの作成
btn_exe.place(x=x00+300,y=y00+num*dy)

#----------------------------------------------------------------
ss = 'Box文字編集'; num = 1
#----------------------------------------------------------------
btn_help = tk.Button(root,text = ss,command = push_cb_edit,bg=btn_bcol,fg=btn_tcol) #ボタンの作成
btn_help.place(x=x00+150,y=y00+num*dy)



#---------------------------------------------------
ss = 'マーク追加、削除'; num = 0
#---------------------------------------------------
btn = tk.Button(root,text = ss,command = push_mark,bg=btn_bcol,fg=btn_tcol) #ボタンの作成
btn.place(x=x01,y=y00+num*dy)

# Combobox
v_mk = StringVar()
cb_mk = ttk.Combobox(root, width=2, textvariable=v_mk)
cb_mk['values']=ss_cb_mk
cb_mk.set("t"); mk_no = 5
cb_mk.place(x=x00, y=y00+num*dy)

#---------------------------------------------------
ss = '(R)化'; num = 1
#---------------------------------------------------
btn = tk.Button(root,text = ss,command = push_rr,bg='orange',fg='black') #ボタンの作成
btn.place(x=x00,y=y00+num*dy)

#---------------------------------------------------
ss = '(参考)追加、削除'; num = 1
#---------------------------------------------------
btn = tk.Button(root,text = ss,command = push_kk,bg=btn_bcol,fg=btn_tcol) #ボタンの作成
btn.place(x=x01,y=y00+num*dy)

#---------------------------------------------------
ss = '引抜  追加、削除'; num = 2  # FB + 引抜
ss1 = '□ * ×'
#---------------------------------------------------
label = tk.Label(root,text=ss1 ,bg=label_bcol)  #  Labelの作成
label.place(x=x00,y=y00+num*dy)    #  Labelの位置

# Combobox
v_th = StringVar()
cb_th = ttk.Combobox(root, width=2, textvariable=v_th)
cb_th['values']=ss_cb_th
cb_th.set("6")
cb_th.place(x=x00+40, y=y00+num*dy)

btn = tk.Button(root,text = ss,command = push_fbh,bg=btn_bcol,fg=btn_tcol) #ボタンの作成
btn.place(x=x00+80,y=y00+num*dy)

#---------------------------------------------------
ss = '囲'; num = 2
#---------------------------------------------------
btn = tk.Button(root,text = ss,command = push_ad_kakomi,bg='orange',fg='black') #ボタンの作成
btn.place(x=x00+190,y=y00+num*dy)

#---------------------------------------------------
ss = '下'; num = 2
#---------------------------------------------------
btn = tk.Button(root,text = ss,command = push_ad_ubar,bg='orange',fg='black') #ボタンの作成
btn.place(x=x00+220,y=y00+num*dy)

#---------------------------------------------------
ss = ' 追加、削除'; num = 3  # FB
ss1 = '□ * ×'
#---------------------------------------------------
label = tk.Label(root,text=ss1 ,bg=label_bcol)  #  Labelの作成
label.place(x=x00,y=y00+num*dy)    #  Labelの位置

# Combobox
v_t = StringVar()
cb_t = ttk.Combobox(root, width=2, textvariable=v_t)
cb_t['values']=ss_cb_t
cb_t.set("6")
cb_t.place(x=x00+40, y=y00+num*dy)

btn = tk.Button(root,text = ss,command = push_fb,bg=btn_bcol,fg=btn_tcol) #ボタンの作成
btn.place(x=x00+80,y=y00+num*dy)

#-------------------------------------------------------
ss = '半角倍角変換'; num = 3   #push_han_bai
#-------------------------------------------------------
btn = tk.Button(root,text = ss,command = push_han_abi,bg='orange',fg='black') #ボタンの作成
btn.place(x=x00+160,y=y00+num*dy)

#---------------------------------------------------
ss = '個数追加'; num = 4
#---------------------------------------------------
btn = tk.Button(root,text = ss,command = push_num,bg=btn_bcol,fg=btn_tcol) #ボタンの作成
btn.place(x=x01,y=y00+num*dy)

# Combobox
v_ks = StringVar()
cb_ks = ttk.Combobox(root, width=2, textvariable=v_ks)
cb_ks['values']=ss_cb_ks
cb_ks.set("2")
cb_ks.place(x=x00, y=y00+num*dy)

#---------------------------------------------------
ss = '大個数追加'; num = 4
#---------------------------------------------------
btn = tk.Button(root,text = ss,command = push_dnum,bg=btn_bcol,fg=btn_tcol) #ボタンの作成
btn.place(x=x00+170,y=y00+num*dy)

# Combobox
v_dks = StringVar()
cb_dks = ttk.Combobox(root, width=2, textvariable=v_dks)
cb_dks['values']=ss_cb_dks
cb_dks.set("2")
cb_dks.place(x=x00+120, y=y00+num*dy)

#-------------------------------------------------------
ss = '一般仕上げ'; num = 5   #
#-------------------------------------------------------
btn = tk.Button(root,text = ss,command = push_ippan,bg='orange',fg='black') #ボタンの作成
btn.place(x=x00+170,y=y00+num*dy)

#-------------------------------------------------------
ss = 'CL自動回'; num = 6   #push_clrt
#-------------------------------------------------------
btn = tk.Button(root,text = ss,command = push_clrt,bg='orange',fg='black') #ボタンの作成
btn.place(x=x00+170,y=y00+num*dy)

#---------------------------------------------------
ss = 'CL作図'; num = 6
#---------------------------------------------------
btn_exe = tk.Button(root,text = ss,command = push_radial_cl, bg='orange',fg='black') #ボタンの作成
btn_exe.place(x=x00+235,y=y00+num*dy)

#---------------------------------------------------
ss = '展開図'; num = 6
#---------------------------------------------------
btn_exe = tk.Button(root,text = ss,command = push_tenkaizu, bg='orange',fg='black') #ボタンの作成
btn_exe.place(x=x00+290,y=y00+num*dy)

#---------------------------------------------------
ss = 'はめあい'; num = 5
#---------------------------------------------------
btn = tk.Button(root,text = ss,command = push_ha, bg=btn_bcol,fg=btn_tcol) #ボタンの作成
btn.place(x=x01,y=y00+num*dy)

# Combobox
v_ha = StringVar()
cb_ha = ttk.Combobox(root, width=3, textvariable=v_ha)
cb_ha['values']=ss_cb_ha
cb_ha.set("h8")
cb_ha.place(x=x00, y=y00+num*dy)

#----------------------------------------------------------------
#  txt_chg
ss = '文字置換'; num =5 
#----------------------------------------------------------------
btn = tk.Button(root,text = ss,command = push_txt_chg, bg='orange',fg='black') #ボタンの作成
btn.place(x=x00+105,y=y00+num*dy)

#---------------------------------------------------
ss = '公差'; num = 6
#--------------------------------------------------
btn = tk.Button(root,text = ss,command = push_ksa, bg=btn_bcol,fg=btn_tcol) #ボタンの作成
btn.place(x=x00+130,y=y00+num*dy)

# Combobox
v_ksa = StringVar()
cb_ksa = ttk.Combobox(root, width=15, textvariable=v_ksa)
cb_ksa['values']=ss_cb_ksa
cb_ksa.set("+1/0")
cb_ksa.place(x=x00, y=y00+num*dy)


#---------------------------------------------------
ss = '後置文字追加'; num = 7
#---------------------------------------------------
btn = tk.Button(root,text = ss,command = push_backword,bg=btn_bcol,fg=btn_tcol) #ボタンの作成
btn.place(x=x00+130,y=y00+num*dy)

# Combobox
v_kt = StringVar()
cb_kt = ttk.Combobox(root, width=15, textvariable=v_kt)
cb_kt['values']=ss_cb_kt
cb_kt.set("キリ")
cb_kt.place(x=x00, y=y00+num*dy)

#---------------------------------------------------
ss = '穴長寸'; num = 7
#---------------------------------------------------
btn_exe = tk.Button(root,text = ss,command = push_dan_kousa, bg='orange',fg='black') #ボタンの作成
btn_exe.place(x=x00+290,y=y00+num*dy)


#---------------------------------------------------
ss = '下置文字追加'; num = 8
#---------------------------------------------------
btn = tk.Button(root,text = ss,command = push_downword,bg=btn_bcol,fg=btn_tcol) #ボタンの作成
btn.place(x=x00+130,y=y00+num*dy)

# Combobox
v_st = StringVar()
cb_st = ttk.Combobox(root, width=15, textvariable=v_st)
cb_st['values']=ss_cb_st
cb_st.set("円周等分")
cb_st.place(x=x00, y=y00+num*dy)

#---------------------------------------------------
ss = '寸法桁'; num = 9
#---------------------------------------------------
btn = tk.Button(root,text = ss,command = push_dim,bg=btn_bcol,fg=btn_tcol) #ボタンの作成
btn.place(x=x01,y=y00+num*dy)

# Combobox
v_dim = StringVar()
cb_dim = ttk.Combobox(root, width=2, textvariable=v_dim)
cb_dim['values']=ss_cb_dim
cb_dim.set("-1")
cb_dim.place(x=x00, y=y00+num*dy)

#---------------------------------------------------
ss = '外周角度'; num = 9
#---------------------------------------------------
btn = tk.Button(root,text = ss,command = push_downdeg,bg=btn_bcol,fg=btn_tcol) #ボタンの作成
btn.place(x=x00+180,y=y00+num*dy)

# Combobox
v_dg = StringVar()
cb_dg = ttk.Combobox(root, width=8, textvariable=v_dg)
cb_dg['values']=ss_cb_dg
cb_dg.set("外径入力")
cb_dg.place(x=x00+105, y=y00+num*dy)

#-------------------------------------------------------
ss = '(個数)タップ寸法注記作成'; num = 10   #push_tks
#-------------------------------------------------------
btn = tk.Button(root,text = ss,command = push_tks,bg=btn_bcol,fg=btn_tcol) #ボタンの作成
btn.place(x=x01,y=y00+num*dy)

# Combobox
v_tks = StringVar()
cb_tks = ttk.Combobox(root, width=2, textvariable=v_tks)
cb_tks['values']=ss_cb_tks
cb_tks.set("2")
cb_tks.place(x=x00, y=y00+num*dy)

#-------------------------------------------------------
ss = '長さ寸法公差'; num = 10   #push_mlk
#-------------------------------------------------------
btn = tk.Button(root,text = ss,command = push_mlk,bg=btn_bcol,fg=btn_tcol) #ボタンの作成
btn.place(x=x00+200,y=y00+num*dy)

#---------------------------------------------------
ss = '実寸化'; num = 11
#---------------------------------------------------
btn = tk.Button(root,text = ss,command = push_t,bg='orange',fg='black') #ボタンの作成
btn.place(x=x00,y=y00+num*dy)


#---------------------------------------------------
ss = '連続角度寸法'; num = 11
#---------------------------------------------------
btn = tk.Button(root,text = ss,command = push_srs_ang, bg=btn_bcol,fg=btn_tcol) #ボタンの作成
btn.place(x=x01,y=y00+num*dy)

#---------------------------------------------------
ss = '非表示'; num = 11
#---------------------------------------------------
btn = tk.Button(root,text = ss,command = push_lay200_of,bg='red',fg='black') #ボタンの作成
btn.place(x=x00+140,y=y00+num*dy)

#---------------------------------------------------
ss = '表示'; num = 11
#---------------------------------------------------
btn = tk.Button(root,text = ss,command = push_lay200_on,bg='red',fg='black') #ボタンの作成
btn.place(x=x00+190,y=y00+num*dy)

#---------------------------------------------------
#ss = '図枠、表題欄作成i(工事中)'; num = 11
#---------------------------------------------------
#btn = tk.Button(root,text = ss,command = push_zwk, bg=btn_bcol,fg=btn_tcol) #ボタンの作成
#btn.place(x=x01,y=y00+num*dy)

# Combobox
#v_zwk = StringVar()
#cb_zwk = ttk.Combobox(root, width=4, textvariable=v_zwk)
#cb_zwk['values']=ss_cb_zwk
#cb_zwk.set("A4B")
#cb_zwk.place(x=x00, y=y00+num*dy)



#---------------------------------------------------
ss = '@GOもしくは他のコマンド選択で終了'; num = 12
#---------------------------------------------------
e_msg = tk.Entry(root,width=55,bg=e_bcol)  #  エントリー部品の生成
e_msg.place(x=x00,y=y00 + num*dy)
e_msg.insert(tk.END,ss)
#label_cmnt= tk.Label(root,text=ss ,bg=label_bcol)  # kwd Labelの作成
#label_cmnt.place(x=x00+20,y=y00+(num)*dy)    # kwd Labelの位置


root.protocol("WM_DELETE_WINDOW", on_closing)
root.mainloop()
